# Filenuke

[![Build Status](https://travis-ci.org/beardog108/filenuke.svg?branch=master)](https://travis-ci.org/beardog108/filenuke)

Secure file erasure Python program and module.

# CLI usage

Specify the root directory or file to be erased with 2 overwrites as the first argument.



**Please note that userland has limitations and that this script is now well tested**